aboutsummaryrefslogtreecommitdiffstats
path: root/host/lib/usrp/b100/codec_ctrl.hpp
diff options
context:
space:
mode:
authorNicholas Corgan <nick.corgan@ettus.com>2014-08-13 08:44:31 -0700
committerMartin Braun <martin.braun@ettus.com>2014-09-01 17:58:24 +0200
commit654c5b06c086ce8b13a5be07e680004c96da8501 (patch)
treebe8adaf06d3b1cebbd20e1b1856df61bfa06ce87 /host/lib/usrp/b100/codec_ctrl.hpp
parentd88ae533c48495dbb86ca5fe2e7ddd05ab3c8a4e (diff)
downloaduhd-654c5b06c086ce8b13a5be07e680004c96da8501.tar.gz
uhd-654c5b06c086ce8b13a5be07e680004c96da8501.tar.bz2
uhd-654c5b06c086ce8b13a5be07e680004c96da8501.zip
Added missing pure virtual destructors to base classes
Diffstat (limited to 'host/lib/usrp/b100/codec_ctrl.hpp')
-rw-r--r--host/lib/usrp/b100/codec_ctrl.hpp6
1 files changed, 4 insertions, 2 deletions
diff --git a/host/lib/usrp/b100/codec_ctrl.hpp b/host/lib/usrp/b100/codec_ctrl.hpp
index 1f7bdef09..78e4ea827 100644
--- a/host/lib/usrp/b100/codec_ctrl.hpp
+++ b/host/lib/usrp/b100/codec_ctrl.hpp
@@ -1,5 +1,5 @@
//
-// Copyright 2011 Ettus Research LLC
+// Copyright 2011,2014 Ettus Research LLC
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
#include <boost/utility.hpp>
/*!
* The usrp-e codec control:
* - Init/power down codec.
* - Read aux adc, write aux dac.
*/
@@ -35,6 +35,8 @@ public:
static const uhd::gain_range_t tx_pga_gain_range;
static const uhd::gain_range_t rx_pga_gain_range;
+ virtual ~b100_codec_ctrl(void) = 0;
+
/*!
* Make a new codec control object.
* \param iface the usrp_e iface object
@@ -24,7 +24,7 @@
#include <boost/utility.hpp>
/*!
- * The usrp-e codec control:
+ * The B100 codec control:
* - Init/power down codec.
* - Read aux adc, write aux dac.